@@ -3,6 +3,7 @@ use std::ops::{Deref, DerefMut};
 
 use async_trait::async_trait;
 use bson::Bson;
+use bson::spec::BinarySubtype;
 use futures::Future;
 use rbatis_core::db::DBExecResult;
 use serde::de::DeserializeOwned;
@@ -16,7 +17,7 @@ use crate::plugin::page::{IPageRequest, Page};
 use crate::rbatis::Rbatis;
 use crate::utils::string_util;
 use futures::executor::block_on;
-use rbatis_core::Format;
+use rbatis_core::{DateTimeNative, Format};
 
 
 /// must be only one have Some(Value)
@@ -185,16 +186,20 @@ impl<'b> RBatisConnExecutor<'b> {
 fn bson_arr_to_string(arg: Vec<Bson>) -> (Vec<Bson>, String) {
     let b = Bson::Array(arg);
     #[cfg(feature = "format_bson")]
-    let s = b.do_format();
-    #[cfg(not(feature = "format_bson"))]
+        {
+            let s = b.do_format();
+            log::info!("[rbatis] [format_bson] => {}", s);
+        }
+
     let s = b.to_string();
-    match b {
+    return match b {
         Bson::Array(arr) => {
-            return (arr, s);
+            (arr, s)
+        }
+        _ => {
+            (vec![], s)
         }
-        _ => {}
     }
-    return (vec![], s);
 }
 
 #[async_trait]
